/**
 * Ticketack
 *
 * @author Belkacem Alidra <belkacem.alidra@netoxygen.ch>
 */
var TicketackControllers = angular.module('ticketack.controllers', []);
var TicketackServices    = angular.module('ticketack.services', ['ngResource', 'underscore']);

angular.module('ticketack', [
    'ionic', 'ngCordova',
    'ionic.service.core', 'ionic.service.push','ionic.service.analytics',
    'ticketack.controllers', 'ticketack.services', 'pascalprecht.translate',
    'ngOnload', 'pdf'
])

.run(function(
        $rootScope, $state,
        $ionicPlatform, $ionicAnalytics,
        $cordovaGlobalization, $cordovaNetwork,
        Cart, Toast, Movies, LocalStorage) {
    $ionicPlatform.ready(function() {

        /* Let's save current state on each state change */
        /*$rootScope.$on('$stateChangeSuccess', function (event, toState, toParams, fromState, fromParams) {
            LocalStorage.setObject('last_state', toState);
            LocalStorage.setObject('last_state_params', toParams);
        });*/

        /* Handle connection state */
        if (!ionic.Platform.is('browser') && $cordovaNetwork.isOffline())
            $rootScope.is_offline = true;
        $rootScope.$on('$cordovaNetwork:online', function(event, networkState) {
            $rootScope.is_offline = false;
            Movies.all();
        });
        $rootScope.$on('$cordovaNetwork:offline', function(event, networkState) {
            $rootScope.is_offline = true;
            Toast.error('Vous n\'êtes plus connecté à internet');
        });

        /* Load user cart */
        Cart.get();

        if (!ionic.Platform.is('browser')) {
            /* Start analytics */
            $ionicAnalytics.register();

            /* Register user for push notifications */
            Ionic.io();
            var user = Ionic.User.current();
            if (!user.id)
                user.id = Ionic.User.anonymousId();

            user.set('version', '1.0.6');

            var push = new Ionic.Push({ "debug": false });
            push.register(function(pushToken) {
                user.addPushToken(pushToken);
                user.save();
            });

            $cordovaGlobalization.getPreferredLanguage(function (result) {
                    $translateProvider.preferredLanguage(result.value);
                },
                function (error) {
                    $translateProvider.preferredLanguage('fr-FR');
                }
            );
        }

        /*$translateProvider
            .determinePreferredLanguage(function() { return 'fr_FR'; })
            .fallbackLanguage('en-EN')
            .preferredLanguage('fr_FR');*/
        // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
        // for form inputs)
        if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
            cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
            // Disabke native scrolling
            cordova.plugins.Keyboard.disableScroll(true);

        }
        if (window.StatusBar) {
            // org.apache.cordova.statusbar required
            StatusBar.styleDefault();
        }
    });
})

.config(function($stateProvider, $urlRouterProvider, $httpProvider, $ionicConfigProvider, $translateProvider) {

    //$ionicConfigProvider.backButton.text('').icon('ion-ios-arrow-left');

    // Use JS scrolling instead of native scrolling
    $ionicConfigProvider.scrolling.jsScrolling(true);

    // Set translations
    $translateProvider.translations('fr-FR', translation_fr);
    $translateProvider.translations('en-EN', translation_en);
    $translateProvider.preferredLanguage('fr-FR');
    $translateProvider.fallbackLanguage('en-EN');
    $translateProvider.useSanitizeValueStrategy('escape');

    function serialize(obj, prefix) {
        var str = [];
        for (var p in obj) {
            if (obj.hasOwnProperty(p)) {
                var k = prefix ? prefix + "[" + p + "]" : p,
                v = obj[p];
                str.push(typeof v == "object" ?
                serialize(v, k) :
                encodeURIComponent(k) + "=" + encodeURIComponent(v));
            }
        }
        return str.join("&");
    }

    // send all requests payload as query string
    $httpProvider.defaults.transformRequest = function(data) {
        if (data === undefined) {
            return data;
        }
        return serialize(data);
    };

    // set all post requests content type
    $httpProvider.defaults.headers.post['Content-Type'] = 'application/x-www-form-urlencoded; charset=UTF-8';

    // Ionic uses AngularUI Router which uses the concept of states
    // Learn more here: https://github.com/angular-ui/ui-router
    // Set up the various states which the app can be in.
    // Each state's controller can be found in controllers.js
    $stateProvider

    .state('loading', {
        url: '/loading',
        templateUrl: 'templates/loading.html',
        controller: 'LoadingCtrl'
    })
    .state('dashboard', {
        url: '/dashboard',
        templateUrl: 'templates/dashboard.html',
        controller: 'DashboardCtrl'
    })

    // setup an abstract state for the tabs directive
    .state('tab', {
        url: '/tab',
        abstract: true,
        templateUrl: 'templates/tabs.html'
    })

    .state('tab.program', {
        url: '/program',
        views: {
            'tab-program': {
                templateUrl: 'templates/program.html',
                controller: 'ProgramCtrl'
            }
        }
    })
    .state('tab.movie', {
        url: '/program/:movie_id',
        views: {
            'tab-program': {
                templateUrl: 'templates/movie.html',
                controller: 'MovieCtrl'
            }
        }
    })

    .state('tab.now', {
        url: '/now',
        views: {
            'tab-now': {
                templateUrl: 'templates/now.html',
                controller: 'NowCtrl'
            }
        }
    })
    .state('tab.now_movie', {
        url: '/now/:movie_id',
        views: {
            'tab-now': {
                templateUrl: 'templates/movie.html',
                controller: 'MovieCtrl'
            }
        }
    })
    .state('tab.favs', {
        url: '/favs',
        views: {
            'tab-favs': {
                templateUrl: 'templates/favs.html',
                controller: 'FavsCtrl'
            }
        }
    })
    .state('tab.favs_movie', {
        url: '/favs/:movie_id',
        views: {
            'tab-favs': {
                templateUrl: 'templates/movie.html',
                controller: 'MovieCtrl'
            }
        }
    })
    .state('tab.cart', {
        url: '/cart',
        views: {
            'tab-cart': {
                templateUrl: 'templates/cart.html',
                controller: 'CartCtrl'
            }
        }
    })
    .state('tab.cart_payment', {
        url: '/cart/payment',
        views: {
            'tab-cart': {
                templateUrl: 'templates/payment.html',
                controller: 'PaymentCtrl'
            }
        }
    })
    .state('tab.tickets', {
        url: '/tickets',
        views: {
            'tab-tickets': {
                templateUrl: 'templates/tickets.html',
                controller: 'TicketsCtrl'
            }
        }
    })
    .state('tab.tickets_pdf', {
        url: '/tickets/pdf/:ticket_id',
        views: {
            'tab-tickets': {
                templateUrl: 'templates/pdf.html',
                controller: 'TicketPdfCtrl'
            }
        }
    })
    .state('tab.tickets_pass', {
        url: '/tickets/pass/:pass_id',
        views: {
            'tab-tickets': {
                templateUrl: 'templates/pass.html',
                controller: 'PassCtrl'
            }
        }
    })
    .state('tab.tickets_buy_pass', {
        url: '/tickets/buy_pass',
        views: {
            'tab-tickets': {
                templateUrl: 'templates/buy_pass.html',
                controller: 'BuyPassCtrl'
            }
        }
    });

    // if none of the above states are matched, use this as the fallback
    //$urlRouterProvider.otherwise('/loading');
    $urlRouterProvider.otherwise('/dashboard');
}).filter('groupByMonthYear', function($parse) {

		var dividers = {};

		return function(input) {
			if (!input || !input.length) return;

			var output = [],
				previousDate,
				currentDate;

			for (var i = 0, ii = input.length; i < ii && (item = input[i]); i++) {
				currentDate = moment(item.start_at);
				if (!previousDate ||
					currentDate.day() != previousDate.day() ||
    				currentDate.month() != previousDate.month() ||
					currentDate.year() != previousDate.year()) {

                        var dividerId = currentDate.format('MMYYYYDD');

    					if (!dividers[dividerId]) {
    						dividers[dividerId] = {
    							isDivider: true,
    							divider: currentDate.format('YYYY-MM-DD')
    						};
    					}

					output.push(dividers[dividerId]);

				}
				output.push(item);

				previousDate = currentDate;
			}

			return output;
		};

	})

	.directive('dividerCollectionRepeat', function($parse) {
		return {
			priority: 1001,
			compile: compile
		};

		function compile (element, attr) {
			var height = attr.itemHeight || '120';
    		attr.$set('itemHeight', 'item.isDivider ? 37 : ' + height);

			element.children().attr('ng-hide', 'item.isDivider');
			element.prepend(
				'<h4 class="assertive ng-hide text-center" ng-show="item.isDivider"><strong><i class="icon ion-ios-calendar-outline"></i> {{ item.divider | date:"EEEE d MMMM" | uppercase }}</strong></h4>'
			);
		}
	});;
