/**
 * Favorites Controller
 *
 * Favorites are stored in the local storage as object with the keys:
 *  - movie_id
 *  - screening_id
 *  - start_at
 *
 * @author Belkacem Alidra <belkacem.alidra@netoxygen.ch>
 */
TicketackControllers.controller('FavsCtrl', function(
    $scope, $rootScope, $state,
    Movies, LocalStorage, _) {

    /* Better to make http calls inside a ionic event handler... */
    $scope.$on('$ionicView.beforeEnter', function(e) {
        /* Let's save this screen as last state */
        LocalStorage.setObject('last_state', $state.current);
        LocalStorage.setObject('last_state_params', {});

        /* Array of movies indexed by day */
        $scope.favs_movies     = {};

        /* Load the favorites from the Local Storage */
        var stored_favs_movies = LocalStorage.getArray('favorites');

        /* We get the number of unique movies: it's used by the view
         * to show/hide some text.
         */
        $scope.nb_favs_movies  = stored_favs_movies.length;

        /* We build the favs_movies array */
        _.each(stored_favs_movies, function(f) {

            /* Fetch the movies: call the API only once */
            Movies.screening(f.movie_id, f.screening_id, function(err, movie, screening) {
                if (err)
                    return false;
                var screening_day = moment(f.start_at).format("YYYY-MM-DD");
				movie.start_at_in_fav = screening.start_at;
                movie.stop_at_in_fav  = screening.stop_at;

                if (_.isUndefined($scope.favs_movies[screening_day]))
                    $scope.favs_movies[screening_day] = [ movie ];
                else
                    $scope.favs_movies[screening_day].push(movie);
            });
        });
    });
})
