/**
 * Program Controller
 * @author Belkacem Alidra <belkacem.alidra@netoxygen.ch>
 */
TicketackControllers.controller('ProgramCtrl', function(
    $scope, $rootScope, $state,
    $ionicScrollDelegate, $ionicSlideBoxDelegate, $translate,
    Movies, Config, Toast, LocalStorage, _) {

    /* Needed here to initialize the cart badge binding */
    $scope.nb_items_in_cart = $rootScope.nb_items_in_cart;
    /* Active slide */
    $scope.active_slide     = 0;
    /* Movies: array indexed by days and containing all the Movies. */
    $scope.movies           = [];
    /* Array of days: used by the slide box */
    $scope.days             = [];
    /* The section filters: sections are defined in the config  */
    $scope.sections         = Config.sections;
    /* Selected section */
    $scope.selected_section = undefined
    /* Used to activate the good slide */
    $scope.selected_day     = "";

    $scope.show_by_day      = false;

    $scope.search = {"text": "" };

    /* Let's save the scroll position each time we leave this view */
    $rootScope.$on('$stateChangeStart', function(e) {
        var handle = $ionicScrollDelegate.$getByHandle('program_scroll');
        if (handle && _.isObject(handle.getScrollPosition()))
            LocalStorage.setObject('program_scroll_position', handle.getScrollPosition());
    });

    /* Better to make http calls inside a ionic event handler... */
    $scope.$on('$ionicView.beforeEnter', function(e) {
        Toast.loading();

        /* Let's save this screen as last state */
        LocalStorage.setObject('last_state', $state.current);
        LocalStorage.setObject('last_state_params', {});

        $scope.no_content_message = "";

        var selected_section = LocalStorage.get('selected_section', undefined);
        if (!_.isEmpty(selected_section))
            $scope.selected_section = selected_section;

        /* Fetch the movies: call the API only once */
        Movies.all(function(err, movies, days) {

            Toast.hide();

            if (err) {
                Toast.error(err.error);
            }
            $scope.screenings = [];
            _.each(movies, function(m) {
                _.each(m.screenings, function(s) {
        		    var screening = {
            			name: s.title.fr ? s.title.fr : s.title.original,
            			start_at: s.start_at,
                        stop_at: s.stop_at,
            			movie: m,
            			section: m.section
        		    };
                    $scope.screenings.push(screening);
                });
            });

            $scope.screenings = _.sortBy($scope.screenings, function(s) {
                return s.start_at;
            })

            delete movies;
            delete days;

            /* Select today if it is in the days */
            if (!_.isEmpty($scope.days)) {
                var today = moment().format('YYYY-MM-DD');
                if (_.contains($scope.days, today)) {
                    $scope.selected_day = today;
                } else {
                    $scope.selected_day = $scope.days[0];
                }
            }

            /* Restore the last scroll position if any */
            var last_scroll_position = LocalStorage.getObject('program_scroll_position', null);
            if (_.isObject(last_scroll_position)) {
                var handle = $ionicScrollDelegate.$getByHandle('program_scroll');
                handle.scrollTo(last_scroll_position.left, last_scroll_position.top, /*animate*/false);
            }

            /* Refresh the slide box */
            $ionicSlideBoxDelegate.update();
        });
    });

    /* On slide changed */
    $scope.slideHasChanged = function(index) {
        $scope.active_slide = index;
        $ionicScrollDelegate.scrollTop();
    }

    /* Manually change slide, on button click */
    $scope.change_slide = function(index) {
        $scope.active_slide = index;
    };

    /* Change section filter, on button click */
    $scope.select_section = function(selected_section) {
        if ($scope.selected_section == selected_section)
            $scope.selected_section = undefined;
        else
            $scope.selected_section = selected_section;

        _.each(Config.sections, function(section, lang_key) {
            if (section == selected_section)
                return $translate("NO_" + lang_key + "_THIS_DAY").then(function (translation) {
                    $scope.no_content_message = translation;
                });

        });

        LocalStorage.set('selected_section', $scope.selected_section);
    };
});
