/**
 * Tickets Controller
 * @author Belkacem Alidra <belkacem.alidra@netoxygen.ch>
 */
TicketackControllers.controller('TicketsCtrl', function(
    $scope, $rootScope,
    $ionicAnalytics, $cordovaBarcodeScanner,
    Cart, Tickets, Movies, Toast, LocalStorage, _) {

    /* The ticket bookings */
    $scope.bookings      = [];

    /* One time tickets */
    $scope.one_times     = [];

    /* Pass */
    $scope.pass          = [];

    /* Ticket number and key are stored in the Local Storage */
    $scope.ticket_number = LocalStorage.get('ticket_number');
    $scope.ticket_key    = LocalStorage.get('ticket_key');

    /* Which category we show: one times or pass */
    $scope.showed = 'one_times';

    /* Better to make http calls inside a ionic event handler... */
    $scope.$on('$ionicView.enter', function(e) {
        /* And we check if we have some one time tickets */
        Tickets.get(function(err, one_times, pass) {
            if (!err) {
                $scope.one_times = one_times;
                $scope.pass      = pass;
                /* Get the current pass, if any */
                $scope.current_pass = Tickets.get_current_pass();

                if (_.isNull($scope.current_pass) && $scope.pass.length > 0) {
                    $scope.activate_pass($scope.pass[0]);
                }
            }
        });
    });

    $scope.scan = function() {
        // Pass
        //Tickets.fetch_ticket_by_url("HTTPS://TKT.LU/743EQ22MWNE4JCYEQOFDXTBKAY");
        // One time
        //Tickets.fetch_ticket_by_url("HTTPS://TKT.LU/ZD4OL2NMEJC7HFGLOD7JJKV2GE");
        $cordovaBarcodeScanner
            .scan()
            .then(function(data) {
                
                if (data.cancelled == 1)
                    return false;

                if (_.isEmpty(data.text))
                    return Toast.error("Billet invalide");

                Tickets.fetch_ticket_by_url(data.text, function(err, ticket) {
                    if (err)
                        return Toast.error("Une erreur est survenue");


                    /* Get the current pass, if any */
                    $scope.current_pass = Tickets.get_current_pass();

                    return Toast.success("Votre billet a bien été importé");
                })
            }, function(error) {
                Toast.error("Une erreur est survenue");
            });
    }

    /**
     * Set the current pass, which is used for booking
     */
    $scope.activate_pass = function(ticket) {
        Toast.loading();
        Tickets.set_current_pass(ticket.ticket_id, function(err, pass) {
            Toast.hide();
            if (err)
                return Toast.error("Une erreur est survenue");

            /* Get the current pass, if any */
            $scope.current_pass = Tickets.get_current_pass();
        });
    };
});
